==> mio_client-1.2.2-py3-none-any.whl: mio/common.py <==
# Copyright 2022 Datum Technology Corporation
# SPDX-License-Identifier: Apache-2.0 WITH SHL-2.1
########################################################################################################################


from mio import cfg
from mio import cache
import sys
import collections
import os
import yaml
import shutil
from yaml.loader import SafeLoader
from datetime import datetime
import hashlib
from alive_progress import alive_bar


def dbg(msg):
    if cfg.dbg:
        print("\033[35m\033[1m[mio-dbg] " + msg + " \033[0m")


def info(msg):
    print("\033[36m\033[1m[mio] " + msg + " \033[0m")


def warning(msg):
    print("\033[33m\033[1m[mio-warning] " + msg + " \033[0m")


def error(msg):
    print("\033[31m\033[1m[mio-error] " + msg + " \033[0m")


def fatal(msg):
    print("\033[31m\033[1m[mio-fatal] " + msg + " \033[0m")
    cache.write_caches_to_disk()
    sys.exit(0)


def banner(msg):
    print("\033[1;35m[mio] *** " + msg + " ***\033[0m")


def prompt(msg):
    return input("\033[36m\033[1m[mio] " + msg + " \033[0m")


def exit(dump_cache=True):
    dbg("Exiting gracefully")
    if dump_cache:
        cache.write_caches_to_disk()
    sys.exit(0)


def get_simulator_short_name(cli_args):
    if cli_args['simulator'] == "vivado":
        return "viv"
    elif cli_args['simulator'] == "vcs":
        return "vcs"
    elif cli_args['simulator'] == "metrics":
        return "mtr"
    elif cli_args['simulator'] == "xcelium":
        return "xcl"
    elif cli_args['simulator'] == "questa":
        return "qst"
    elif cli_args['simulator'] == "riviera":
        return "riv"


def merge_dict(d1, d2):
    """
    Modifies d1 in-place to contain values from d2.  If any value
    in d1 is a dictionary (or dict-like), *and* the corresponding
    value in d2 is also a dictionary, then merge them in-place.
    """
    for k, v2 in d2.items():
        v1 = d1.get(k)  # returns None if v1 has no value for this key
        if (isinstance(v1, collections.Mapping) and
                isinstance(v2, collections.Mapping)):
            merge_dict(v1, v2)
        else:
            d1[k] = v2


def timestamp():
    return datetime.now().strftime("%Y/%m/%d-%H:%M:%S")




def create_dir(path):
    if not os.path.exists(path):
        dbg("Creating directory at " + path)
        os.mkdir(path)
        dbg("Created directory at " + path)
    else:
        dbg("Not creating directory at " + path + " because it already exists")


def create_file(path):
    if not os.path.exists(path):
        dbg("Creating file at " + path)
        f = open(path, "x")
        f.close()
        dbg("Created file at " + path)
    else:
        dbg("Not creating file at " + path + " because it already exists")


def remove_dir(path):
    if os.path.exists(path):
        dbg(f"Removing directory '{path}'")
        shutil.rmtree(path)


def copy_tree(src, dst, symlinks=False, ignore=None):
    for item in os.listdir(src):
        s = os.path.join(src, item)
        d = os.path.join(dst, item)
        if os.path.isdir(s):
            shutil.copytree(s, d, symlinks, ignore)
        else:
            shutil.copy2(s, d)


def calc_file_hash(path):
    hash = hashlib.md5(open(path,'rb').read()).hexdigest()
    dbg("Hash for file " + path  + " is '" + hash + "'")
    return hash


def create_common_files():
    dbg("Creating common directories and files")
    try:
        create_dir(cfg.mio_data_dir        )
        create_dir(cfg.dependencies_path   )
        create_dir(cfg.mio_user_dir        )
        create_dir(cfg.user_global_ips_path)
        create_file(cfg.job_history_file_path)
        create_file(cfg.ip_cache_file_path   )
        create_file(cfg.fsoc_cache_file_path )
        
        with open(cfg.job_history_file_path, 'r') as yaml_file_read:
            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
            if not ymlr:
                ymlr = { "history" : {}}
                dbg("Initializing job history file at " + cfg.job_history_file_path)
                with open(cfg.job_history_file_path, 'w') as yaml_file_write:
                    yaml.dump(ymlr, yaml_file_write)
            cfg.job_history = ymlr['history']
        
        with open(cfg.ip_cache_file_path, 'r') as yaml_file_read:
            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
            if not ymlr:
                ymlr = {
                    "local"    : {},
                    "external" : {}
                }
                dbg("Initializing IP cache file at " + cfg.ip_cache_file_path)
                cfg.fresh_ip_cache = True
                with open(cfg.ip_cache_file_path, 'w') as yaml_file_write:
                    yaml.dump(ymlr, yaml_file_write)
        
        with open(cfg.fsoc_cache_file_path, 'r') as yaml_file_read:
            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
            if not ymlr:
                ymlr = {"cores" : {}}
                dbg("Initializing FuseSoC cache file at " + cfg.fsoc_cache_file_path)
                cfg.fresh_soc_cache = True
                with open(cfg.fsoc_cache_file_path, 'w') as yaml_file_write:
                    yaml.dump(ymlr, yaml_file_write)
    except Exception as e:
        print("\033[31m\033[1m[mio-fatal] Could not create work directories and files: " + str(e) + "\033[0m")
        sys.exit(0)

==> mio_client-1.2.6-py3-none-any.whl: mio/common.py <==
# Copyright 2022 Datum Technology Corporation
# SPDX-License-Identifier: Apache-2.0 WITH SHL-2.1
########################################################################################################################


from mio import cfg
from mio import cache
import sys
import collections
import os
import yaml
import shutil
from enum import Enum
from yaml.loader import SafeLoader
from datetime import datetime
import hashlib
from alive_progress import alive_bar


class simulators_enum(Enum):
    SIM_VIVADO  = "viv"
    SIM_METRICS = "mtr"
    SIM_VCS     = "viv"
    SIM_XCELIUM = "xcl"
    SIM_QUESTA  = "qst"
    SIM_RIVIERA = "riv"


def dbg(msg):
    if cfg.dbg:
        print("\033[35m\033[1m[mio-dbg] " + msg + " \033[0m")


def info(msg):
    print("\033[36m\033[1m[mio]\033[0m " + msg)


def warning(msg):
    print("\033[33m\033[1m[mio-warning] " + msg + " \033[0m")


def error(msg):
    print("\033[31m\033[1m[mio-error] " + msg + " \033[0m")


def fatal(msg):
    print("\033[31m\033[1m[mio-fatal] " + msg + " \033[0m")
    cache.write_caches_to_disk()
    print()
    sys.exit(0)


def banner(msg):
    print("\033[1;35m[mio] *** " + msg + " ***\033[0m")


def prompt(msg):
    return input("\033[36m\033[1m[mio]\033[0m " + msg)


def exit(dump_cache=True):
    dbg("Exiting gracefully")
    if dump_cache:
        cache.write_caches_to_disk()
    print()
    sys.exit(0)


def get_simulator_short_name(cli_args):
    if cli_args['simulator'] == "vivado":
        return "viv"
    elif cli_args['simulator'] == "vcs":
        return "vcs"
    elif cli_args['simulator'] == "metrics":
        return "mtr"
    elif cli_args['simulator'] == "xcelium":
        return "xcl"
    elif cli_args['simulator'] == "questa":
        return "qst"
    elif cli_args['simulator'] == "riviera":
        return "riv"


def merge_dict(d1, d2):
    """
    Modifies d1 in-place to contain values from d2.  If any value
    in d1 is a dictionary (or dict-like), *and* the corresponding
    value in d2 is also a dictionary, then merge them in-place.
    """
    for k, v2 in d2.items():
        v1 = d1.get(k)  # returns None if v1 has no value for this key
        if (isinstance(v1, collections.Mapping) and
                isinstance(v2, collections.Mapping)):
            merge_dict(v1, v2)
        else:
            d1[k] = v2


def timestamp():
    return datetime.now().strftime("%Y/%m/%d-%H:%M:%S")




def create_dir(path):
    if not os.path.exists(path):
        dbg("Creating directory at " + path)
        os.mkdir(path)
        dbg("Created directory at " + path)
    else:
        dbg("Not creating directory at " + path + " because it already exists")


def create_file(path):
    if not os.path.exists(path):
        dbg("Creating file at " + path)
        f = open(path, "x")
        f.close()
        dbg("Created file at " + path)
    else:
        dbg("Not creating file at " + path + " because it already exists")


def remove_dir(path):
    if os.path.exists(path):
        dbg(f"Removing directory '{path}'")
        shutil.rmtree(path)


def copy_tree(src, dst, symlinks=False, ignore=None):
    for item in os.listdir(src):
        s = os.path.join(src, item)
        d = os.path.join(dst, item)
        if os.path.isdir(s):
            shutil.copytree(s, d, symlinks, ignore)
        else:
            shutil.copy2(s, d)


def calc_file_hash(path):
    hash = hashlib.md5(open(path,'rb').read()).hexdigest()
    dbg("Hash for file " + path  + " is '" + hash + "'")
    return hash


def create_common_files():
    dbg("Creating common directories and files")
    try:
        create_dir(cfg.mio_data_dir        )
        create_dir(cfg.dependencies_path   )
        create_dir(cfg.mio_user_dir        )
        create_dir(cfg.user_global_ips_path)
        create_file(cfg.job_history_file_path)
        create_file(cfg.ip_cache_file_path   )
        create_file(cfg.fsoc_cache_file_path )
        
        with open(cfg.job_history_file_path, 'r') as yaml_file_read:
            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
            if not ymlr:
                ymlr = { "history" : {}}
                dbg("Initializing job history file at " + cfg.job_history_file_path)
                with open(cfg.job_history_file_path, 'w') as yaml_file_write:
                    yaml.dump(ymlr, yaml_file_write)
            cfg.job_history = ymlr['history']
        
        with open(cfg.ip_cache_file_path, 'r') as yaml_file_read:
            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
            if not ymlr:
                ymlr = {
                    "local"    : {},
                    "external" : {}
                }
                dbg("Initializing IP cache file at " + cfg.ip_cache_file_path)
                cfg.fresh_ip_cache = True
                with open(cfg.ip_cache_file_path, 'w') as yaml_file_write:
                    yaml.dump(ymlr, yaml_file_write)
        
        with open(cfg.fsoc_cache_file_path, 'r') as yaml_file_read:
            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
            if not ymlr:
                ymlr = {"cores" : {}}
                dbg("Initializing FuseSoC cache file at " + cfg.fsoc_cache_file_path)
                cfg.fresh_soc_cache = True
                with open(cfg.fsoc_cache_file_path, 'w') as yaml_file_write:
                    yaml.dump(ymlr, yaml_file_write)
    except Exception as e:
        print("\033[31m\033[1m[mio-fatal] Could not create work directories and files: " + str(e) + "\033[0m")
        sys.exit(0)
